==> haskell-prettyprinter-1.7.1-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter
version:              1.7.1
visibility:           public
id:                   prettyprinter-1.7.1-7x8ULV7tlRe3aOwpDSy6yg
key:                  prettyprinter-1.7.1-7x8ULV7tlRe3aOwpDSy6yg
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:
    Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky, Simon Jakobi

homepage:             http://github.com/quchen/prettyprinter
synopsis:
    A modern, easy to use, well-documented, extensible pretty-printer.

description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md

category:             User Interfaces, Text
abi:                  034575ce900c5aab08c560f163aa5ec1
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Debug
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util Prettyprinter Prettyprinter.Internal
    Prettyprinter.Internal.Debug Prettyprinter.Internal.Type
    Prettyprinter.Render.String Prettyprinter.Render.Text
    Prettyprinter.Render.Tutorials.StackMachineTutorial
    Prettyprinter.Render.Tutorials.TreeRenderingTutorial
    Prettyprinter.Render.Util.Panic
    Prettyprinter.Render.Util.SimpleDocTree
    Prettyprinter.Render.Util.StackMachine Prettyprinter.Symbols.Ascii
    Prettyprinter.Symbols.Unicode Prettyprinter.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/prettyprinter-1.7.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/prettyprinter-1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter
hs-libraries:         HSprettyprinter-1.7.1-7x8ULV7tlRe3aOwpDSy6yg
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-1.7.1-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter
version:              1.7.1
visibility:           public
id:                   prettyprinter-1.7.1-KnGgQk2daq0AGFQwkmg3r7
key:                  prettyprinter-1.7.1-KnGgQk2daq0AGFQwkmg3r7
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:
    Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky, Simon Jakobi

homepage:             http://github.com/quchen/prettyprinter
synopsis:
    A modern, easy to use, well-documented, extensible pretty-printer.

description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md

category:             User Interfaces, Text
abi:                  76170d0f3416cb48d4978cae10088d86
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Debug
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util Prettyprinter Prettyprinter.Internal
    Prettyprinter.Internal.Debug Prettyprinter.Internal.Type
    Prettyprinter.Render.String Prettyprinter.Render.Text
    Prettyprinter.Render.Tutorials.StackMachineTutorial
    Prettyprinter.Render.Tutorials.TreeRenderingTutorial
    Prettyprinter.Render.Util.Panic
    Prettyprinter.Render.Util.SimpleDocTree
    Prettyprinter.Render.Util.StackMachine Prettyprinter.Symbols.Ascii
    Prettyprinter.Symbols.Unicode Prettyprinter.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/prettyprinter-1.7.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/prettyprinter-1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter
hs-libraries:         HSprettyprinter-1.7.1-KnGgQk2daq0AGFQwkmg3r7
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
